# Changelog

## 1.0.4 (2023-06-29)

- Fix NUA Key auth and sentence predict
- Pin Nuclia dependencies
- Fix documentation
- Add `search` method in `NucliaSearch`
- Support TextField upload

## 1.0.3 (2023-06-20)

Initial version with support of KB authentication and NUA
